@@ -1,8 +1,10 @@
 from .base import BackendBase
 from .bk_qiniu import Qiniu
 from .bk_wy import WYSF
+from .bk_minio import MinioBackend
 
 backend_factory = {
     'qiniu': Qiniu,
-    'wysf': WYSF
+    'wysf': WYSF,
+    'minio': MinioBackend
 }
\ No newline at end of file
