@@ -176,7 +176,7 @@ class Client(Singleton):
                 return False, None
             else:
                 ignore_prefix.append(prefix)
-                self.__put_to_cloud(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
+                return self.__put_to_cloud(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
             
     def put_to_cloud(self, path, bucket, bucket_name, tmp=True):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
@@ -204,7 +204,7 @@ class Client(Singleton):
                 return False, None
             else:
                 ignore_prefix.append(prefix)
-                await self.__put_to_cloud_async(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
+                return await self.__put_to_cloud_async(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
 
         
     async def put_to_cloud_async(self, path, bucket, bucket_name, tmp=True):
